/**
 * BNSim is an open-source, parallel, stochastic, and multi-scale modeling
 * platform which integrates various simulation algorithms, together with
 * genetic circuits and chemotaxis pathway models in a 3D environment.
 *
 * BNSim is developed by CMU SLD Group, and released under GPLv2 license
 * Please check http://www.ece.cmu.edu/~sld/bnsim for more information
 *
 * BNSim is developed using C++ and pthread under Linux and Mac OS
 *
 * If you use it for your work, please cite
 * Wei, Guopeng, Paul Bogdan, and Radu Marculescu. "Efficient Modeling and
 * Simulation of Bacteria-Based Nanonetworks with BNSim." Selected Areas in
 * Communications, IEEE Journal on 31.12 (2013): 868-878.
 *
 * @author      Guopeng (Daniel) Wei  danielwei@cmu.edu
 * @version     2.5
 * @since       1.0
 */

#include "core.h"


using namespace BNSim;
using namespace std;

struct Param Sim::param;
Universe* Sim::univ = NULL;
vector<EnvCube *> Sim::cubesList;
vector<Bacteria *> Sim::BacteriaList;
vector<chemicalSpecies> Sim::chemical;

Param::Param(void){
	timeStep= 0.01; // s
	viscosity= 2.7e-3;
	diffusionC= 890; // microns^2/
	WorldSize = new myVector3d(100,100,100);
	cubeNumber.x = cubeNumber.y = cubeNumber.z = 10;
	cubeSize.x = cubeSize.y = cubeSize.z = 10;
	ThreadNumber = 4;  // default dual core processor with hyper-threading
	ChemicalNumber = 1;
	leakyBoundary = false;
	time = 0;
	bacNum = 0;
	workdir = "";
	calibrate =false;
	environmentOnly = false;
	bacteriaOnly = false;
    networkExport = false;
    QST = 0;
    QSD = 0;
    quorumSensing = false;
    chemotaxis = false;
    bacteriaRadius = 1;
    RecordVisit = false;
}

EnvCube::EnvCube() {
	particleNumber = 0;
}
